@@ -1,5 +1,5 @@
 /*
- * "$Id: ipp.c 5495 2006-05-05 17:58:07Z mike $"
+ * "$Id: ipp.c 5724 2006-07-12 19:42:35Z mike $"
  *
  *   IPP backend for the Common UNIX Printing System (CUPS).
  *
@@ -211,7 +211,8 @@ main(int  argc,				/* I - Number of command-line args */
   */
 
   if ((content_type = getenv("FINAL_CONTENT_TYPE")) == NULL)
-    content_type = "application/octet-stream";
+    if ((content_type = getenv("CONTENT_TYPE")) == NULL)
+      content_type = "application/octet-stream";
 
  /*
   * Extract the hostname and printer name from the URI...
@@ -229,6 +230,8 @@ main(int  argc,				/* I - Number of command-line args */
 
   if (!strcmp(method, "https"))
     cupsSetEncryption(HTTP_ENCRYPT_ALWAYS);
+  else
+    cupsSetEncryption(HTTP_ENCRYPT_IF_REQUESTED);
 
  /*
   * See if there are any options...
@@ -276,7 +279,7 @@ main(int  argc,				/* I - Number of command-line args */
             *ptr++ = *optptr++;
 	*ptr = '\0';
 
-	if (*optptr == '+')
+	if (*optptr == '+' || *optptr == '&')
 	  optptr ++;
       }
       else
@@ -1619,5 +1622,5 @@ sigterm_handler(int sig)		/* I - Signal */
 
 
 /*
- * End of "$Id: ipp.c 5495 2006-05-05 17:58:07Z mike $".
+ * End of "$Id: ipp.c 5724 2006-07-12 19:42:35Z mike $".
  */
