@@ -1,5 +1,5 @@
 /*
- * "$Id: snmp.c 5479 2006-05-02 15:03:17Z mike $"
+ * "$Id: snmp.c 5736 2006-07-13 19:59:36Z mike $"
  *
  *   SNMP discovery backend for the Common UNIX Printing System (CUPS).
  *
@@ -77,17 +77,10 @@
  * Include necessary headers.
  */
 
-#include <cups/backend.h>
 #include <cups/http-private.h>
-#include <cups/cups.h>
-#include <cups/string.h>
+#include "backend-private.h"
 #include <cups/array.h>
 #include <cups/file.h>
-#include <errno.h>
-#include <signal.h>
-
-#define SNMP_BACKEND
-#include "ieee1284.c"
 
 
 /*
@@ -391,7 +384,7 @@ add_cache(http_addr_t *addr,		/* I - Device IP address */
 
   debug_printf("DEBUG: add_cache(addr=%p, addrname=\"%s\", uri=\"%s\", "
                   "id=\"%s\", make_and_model=\"%s\")\n",
-               addr, addrname, uri, id ? id :  "(null)",
+               addr, addrname, uri ? uri : "(null)", id ? id :  "(null)",
 	       make_and_model ? make_and_model : "(null)");
 
   temp = calloc(1, sizeof(snmp_cache_t));
@@ -1210,7 +1203,7 @@ static int				/* O - Result of comparison */
 compare_cache(snmp_cache_t *a,		/* I - First cache entry */
               snmp_cache_t *b)		/* I - Second cache entry */
 {
-  return (a->address.ipv4.sin_addr.s_addr - b->address.ipv4.sin_addr.s_addr);
+  return (strcasecmp(a->addrname, b->addrname));
 }
 
 
@@ -1647,6 +1640,14 @@ probe_device(snmp_cache_t *device)	/* I - Device */
 	     !strchr(info->values[0].string.text, ';')))
  	  info = NULL;
 
+       /*
+        * Don't use the printer-make-and-model if it contains a generic
+	* string like "Ricoh IPP Printer"...
+	*/
+
+	if (model && strstr(model->values[0].string.text, "IPP Printer"))
+	  model = NULL;
+
        /*
         * If we don't have a printer-make-and-model string from the printer
 	* but do have the 1284 device ID string, generate a make-and-model
@@ -1656,7 +1657,9 @@ probe_device(snmp_cache_t *device)	/* I - Device */
 	if (model)
           strlcpy(temp, model->values[0].string.text, sizeof(temp));
 	else if (info)
-	  get_make_model(info->values[0].string.text, temp, sizeof(temp));
+	  backendGetMakeModel(info->values[0].string.text, temp, sizeof(temp));
+        else
+	  temp[0] = '\0';
 
         fix_make_model(make_model, temp, sizeof(make_model));
 
@@ -1871,8 +1874,8 @@ read_snmp_response(int fd)		/* I - SNMP socket file descriptor */
   * Find a matching device in the cache...
   */
 
-  key.address = addr;
-  device      = (snmp_cache_t *)cupsArrayFind(Devices, &key);
+  key.addrname = addrname;
+  device       = (snmp_cache_t *)cupsArrayFind(Devices, &key);
 
  /*
   * Process the message...
@@ -1928,8 +1931,8 @@ read_snmp_response(int fd)		/* I - SNMP socket file descriptor */
       * Description is the IEEE-1284 device ID...
       */
 
-      get_make_model(packet.object_value.string, make_model,
-                     sizeof(make_model));
+      backendGetMakeModel(packet.object_value.string, make_model,
+                	  sizeof(make_model));
     }
     else
     {
@@ -2212,5 +2215,5 @@ update_cache(snmp_cache_t *device,	/* I - Device */
 
 
 /*
- * End of "$Id: snmp.c 5479 2006-05-02 15:03:17Z mike $".
+ * End of "$Id: snmp.c 5736 2006-07-13 19:59:36Z mike $".
  */
