@@ -1,5 +1,5 @@
 /*
- * "$Id: http.c 5416 2006-04-17 21:24:17Z mike $"
+ * "$Id: http.c 5753 2006-07-18 19:53:24Z mike $"
  *
  *   HTTP routines for the Common UNIX Printing System (CUPS).
  *
@@ -866,7 +866,7 @@ httpGets(char   *line,			/* I - Line to read into */
       * No newline; see if there is more data to be read...
       */
 
-      if (!http->blocking && !http_wait(http, 1000))
+      if (!http->blocking && !http_wait(http, 10000))
       {
         DEBUG_puts("httpGets: Timed out!");
         http->error = ETIMEDOUT;
@@ -1222,7 +1222,7 @@ httpRead2(http_t *http,			/* I - HTTP connection */
     * Buffer small reads for better performance...
     */
 
-    if (!http->blocking && !httpWait(http, 1000))
+    if (!http->blocking && !httpWait(http, 10000))
       return (0);
 
     if (http->data_remaining > sizeof(http->buffer))
@@ -1285,7 +1285,7 @@ httpRead2(http_t *http,			/* I - HTTP connection */
 #ifdef HAVE_SSL
   else if (http->tls)
   {
-    if (!http->blocking && !httpWait(http, 1000))
+    if (!http->blocking && !httpWait(http, 10000))
       return (0);
 
     bytes = http_read_ssl(http, buffer, length);
@@ -1293,7 +1293,7 @@ httpRead2(http_t *http,			/* I - HTTP connection */
 #endif /* HAVE_SSL */
   else
   {
-    if (!http->blocking && !httpWait(http, 1000))
+    if (!http->blocking && !httpWait(http, 10000))
       return (0);
 
     DEBUG_printf(("httpRead2: reading %d bytes from socket...\n", length));
@@ -1415,13 +1415,11 @@ _httpReadCDSA(
     *dataLength = 0;
 
     if (bytes == 0)
-      result = errSSLClosedAbort;
+      result = errSSLClosedGraceful;
     else if (errno == EAGAIN)
       result = errSSLWouldBlock;
-    else if (errno == EPIPE)
-      result = errSSLClosedAbort;
     else
-      result = errSSLInternal;
+      result = errSSLClosedAbort;
   }
 
   return result;
@@ -1810,6 +1808,16 @@ httpWait(http_t *http,			/* I - HTTP connection */
   if (http->used)
     return (1);
 
+ /*
+  * Flush pending data, if any...
+  */
+
+  if (http->wused)
+  {
+    if (httpFlushWrite(http) < 0)
+      return (0);
+  }
+
  /*
   * If not, check the SSL/TLS buffers and do a select() on the connection...
   */
@@ -1994,10 +2002,8 @@ _httpWriteCDSA(
   
     if (errno == EAGAIN)
       result = errSSLWouldBlock;
-    else if (errno == EPIPE)
-      result = errSSLClosedAbort;
     else
-      result = errSSLInternal;
+      result = errSSLClosedAbort;
   }
 
   return result;
@@ -2337,6 +2343,9 @@ http_setup_ssl(http_t *http)		/* I - HTTP connection */
   if (!error)
     error = SSLSetAllowsAnyRoot(conn->session, true);
 
+  if (!error)
+    error = SSLSetProtocolVersionEnabled(conn->session, kSSLProtocol2, false);
+
   if (!error)
   {
     while ((error = SSLHandshake(conn->session)) == errSSLWouldBlock)
@@ -2802,5 +2811,5 @@ http_write_ssl(http_t     *http,	/* I - HTTP connection */
 
 
 /*
- * End of "$Id: http.c 5416 2006-04-17 21:24:17Z mike $".
+ * End of "$Id: http.c 5753 2006-07-18 19:53:24Z mike $".
  */
