@@ -1,5 +1,5 @@
 /*
- * "$Id: auth.c 5464 2006-04-26 01:34:14Z mike $"
+ * "$Id: auth.c 5643 2006-06-07 20:58:29Z mike $"
  *
  *   Authorization routines for the Common UNIX Printing System (CUPS).
  *
@@ -119,7 +119,7 @@ typedef struct cupsd_authdata_s		/**** Authentication data ****/
  * Local globals...
  */
 
-#if defined(__hpux) && defined(HAVE_LIBPAM)
+#if defined(__hpux) && HAVE_LIBPAM
 static cupsd_authdata_t	*auth_data;	/* Current client being authenticated */
 #endif /* __hpux && HAVE_LIBPAM */
 
@@ -869,9 +869,12 @@ cupsdCheckAuth(
 	    */
 
 	    for (iface = (cupsd_netif_t *)cupsArrayFirst(NetIFList);
-	         iface && !strcmp(masks->mask.name.name, iface->name);
+	         iface;
 		 iface = (cupsd_netif_t *)cupsArrayNext(NetIFList))
 	    {
+              if (strcmp(masks->mask.name.name, iface->name))
+                continue;
+
               if (iface->address.addr.sa_family == AF_INET)
 	      {
 	       /*
@@ -1497,7 +1500,8 @@ cupsdIsAuthorized(cupsd_client_t *con,	/* I - Connection */
 
   cupsdLogMessage(CUPSD_LOG_DEBUG2,
                   "cupsdIsAuthorized: con->uri=\"%s\", con->best=%p(%s)",
-                  con->uri, con->best, con->best ? con->best->location : "");
+                  con->uri, con->best, con->best ? con->best->location ?
+                			   con->best->location : "(null)" : "");
   if (owner)
     cupsdLogMessage(CUPSD_LOG_DEBUG2,
                     "cupsdIsAuthorized: owner=\"%s\"", owner);
@@ -2167,5 +2171,5 @@ to64(char          *s,			/* O - Output string */
 
 
 /*
- * End of "$Id: auth.c 5464 2006-04-26 01:34:14Z mike $".
+ * End of "$Id: auth.c 5643 2006-06-07 20:58:29Z mike $".
  */
