@@ -1,5 +1,5 @@
 /*
- * "$Id: dirsvc.c 5448 2006-04-22 03:57:26Z mike $"
+ * "$Id: dirsvc.c 5724 2006-07-12 19:42:35Z mike $"
  *
  *   Directory services routines for the Common UNIX Printing System (CUPS).
  *
@@ -36,6 +36,7 @@
  *   cupsdStopPolling()            - Stop polling servers as needed.
  *   cupsdUpdateCUPSBrowse()       - Update the browse lists using the CUPS
  *                                   protocol.
+ *   cupsdUpdateLDAPBrowse()       - Scan for new printers via LDAP...
  *   cupsdUpdatePolling()          - Read status messages from the poll daemons.
  *   cupsdUpdateSLPBrowse()        - Get browsing information via SLP.
  *   dequote()                     - Remote quotes from a string.
@@ -211,10 +212,11 @@ cupsdLoadRemoteCache(void)
 	else
           p = cupsdAddPrinter(value);
 
-	p->accepting   = 1;
-	p->state       = IPP_PRINTER_IDLE;
-	p->type        |= CUPS_PRINTER_REMOTE;
-	p->browse_time = now + BrowseTimeout;
+	p->accepting     = 1;
+	p->state         = IPP_PRINTER_IDLE;
+	p->type          |= CUPS_PRINTER_REMOTE;
+	p->browse_time   = now;
+	p->browse_expire = now + BrowseTimeout;
 
        /*
         * Set the default printer as needed...
@@ -251,10 +253,11 @@ cupsdLoadRemoteCache(void)
 	else
           p = cupsdAddClass(value);
 
-	p->accepting   = 1;
-	p->state       = IPP_PRINTER_IDLE;
-	p->type        |= CUPS_PRINTER_REMOTE;
-	p->browse_time = now + BrowseTimeout;
+	p->accepting     = 1;
+	p->state         = IPP_PRINTER_IDLE;
+	p->type          |= CUPS_PRINTER_REMOTE;
+	p->browse_time   = now;
+	p->browse_expire = now + BrowseTimeout;
 
        /*
         * Set the default printer as needed...
@@ -415,8 +418,8 @@ cupsdLoadRemoteCache(void)
       {
         time_t t = atoi(value);
 
-	if (t > (now + BrowseInterval))
-          p->browse_time = t;
+	if (t > p->browse_expire)
+          p->browse_expire = t;
       }
       else
       {
@@ -590,7 +593,7 @@ cupsdSaveRemoteCache(void)
 
     cupsFilePrintf(fp, "Type %d\n", printer->type);
 
-    cupsFilePrintf(fp, "BrowseTime %d\n", (int)printer->browse_time);
+    cupsFilePrintf(fp, "BrowseTime %d\n", (int)printer->browse_expire);
 
     if (printer->info)
       cupsFilePrintf(fp, "Info %s\n", printer->info);
@@ -665,10 +668,10 @@ cupsdSendBrowseDelete(
   * Announce the deletion...
   */
 
-  if (BrowseLocalProtocols & BROWSE_CUPS)
+  if ((BrowseLocalProtocols & BROWSE_CUPS) && BrowseSocket >= 0)
     send_cups_browse(p);
 #ifdef HAVE_LIBSLP
-  if (BrowseLocalProtocols & BROWSE_SLP)
+  if ((BrowseLocalProtocols & BROWSE_SLP) && BrowseSLPHandle)
     slp_dereg_printer(p);
 #endif /* HAVE_LIBSLP */
 }
@@ -905,14 +908,21 @@ cupsdStartBrowsing(void)
     fcntl(BrowseSocket, F_SETFD, fcntl(BrowseSocket, F_GETFD) | FD_CLOEXEC);
 
    /*
-    * Finally, add the socket to the input selection set...
+    * Finally, add the socket to the input selection set as needed...
     */
 
-    cupsdLogMessage(CUPSD_LOG_DEBUG2,
-                    "cupsdStartBrowsing: Adding fd %d to InputSet...",
-                    BrowseSocket);
+    if (BrowseRemoteProtocols & BROWSE_CUPS)
+    {
+     /*
+      * We only listen if we want remote printers...
+      */
 
-    FD_SET(BrowseSocket, InputSet);
+      cupsdLogMessage(CUPSD_LOG_DEBUG2,
+                      "cupsdStartBrowsing: Adding fd %d to InputSet...",
+                      BrowseSocket);
+
+      FD_SET(BrowseSocket, InputSet);
+    }
   }
   else
     BrowseSocket = -1;
@@ -934,6 +944,8 @@ cupsdStartBrowsing(void)
 
     BrowseSLPRefresh = 0;
   }
+  else
+    BrowseSLPHandle = NULL;
 #endif /* HAVE_LIBSLP */
 
 #ifdef HAVE_OPENLDAP
@@ -1161,7 +1173,7 @@ cupsdStopBrowsing(void)
   }
 #endif /* HAVE_LIBSLP */
 
-#ifdef HAVE_OPENDAP
+#ifdef HAVE_OPENLDAP
   if (((BrowseLocalProtocols | BrowseRemoteProtocols) & BROWSE_LDAP) &&
       BrowseLDAPHandle)
   {
@@ -1524,39 +1536,57 @@ cupsdUpdateLDAPBrowse(void)
   * Loop through the available printers...
   */
 
-  if ((e = ldap_first_entry(BrowseLDAPHandle, res)) == NULL)
+  for (e = ldap_first_entry(BrowseLDAPHandle, res);
+       e;
+       e = ldap_next_entry(BrowseLDAPHandle, e))
   {
-    cupsdLogMessage(CUPSD_LOG_ERROR, "Unable to get LDAP printer entry!");
-    return;
-  }
+   /*
+    * Get the required values from this entry...
+    */
+
+    if ((value = ldap_get_values(BrowseLDAPHandle, e,
+                                 "printerDescription")) == NULL)
+      continue;
 
-  while (e)
-  {
-    value = ldap_get_values(BrowseLDAPHandle, e, "printerDescription");
     strlcpy(info, *value, sizeof(info));
     ldap_value_free(value);
 
-    value = ldap_get_values(BrowseLDAPHandle, e, "printerLocation");
+    if ((value = ldap_get_values(BrowseLDAPHandle, e,
+                                 "printerLocation")) == NULL)
+      continue;
+
     strlcpy(location, *value, sizeof(location));
     ldap_value_free(value);
 
-    value = ldap_get_values(BrowseLDAPHandle, e, "printerMakeAndModel");
+    if ((value = ldap_get_values(BrowseLDAPHandle, e,
+                                 "printerMakeAndModel")) == NULL)
+      continue;
+
     strlcpy(make_model, *value, sizeof(make_model));
     ldap_value_free(value);
 
-    value = ldap_get_values(BrowseLDAPHandle, e, "printerType");
+    if ((value = ldap_get_values(BrowseLDAPHandle, e,
+                                 "printerType")) == NULL)
+      continue;
+
     type = atoi(*value);
     ldap_value_free(value);
 
-    value = ldap_get_values(BrowseLDAPHandle, e, "printerURI");
+    if ((value = ldap_get_values(BrowseLDAPHandle, e,
+                                 "printerURI")) == NULL)
+      continue;
+
     strlcpy(uri, *value, sizeof(uri));
     ldap_value_free(value);
 
+   /*
+    * Process the entry as browse data...
+    */
+
     if (!is_local_queue(uri, host, sizeof(host), resource, sizeof(resource)))
       process_browse_data(uri, host, resource, type, IPP_PRINTER_IDLE,
                           location, info, make_model, 0, NULL);
 
-    e = ldap_next_entry(BrowseLDAPHandle, e);
   }
 }
 #endif /* HAVE_OPENLDAP */
@@ -1864,7 +1894,7 @@ process_browse_data(
   hptr   = strchr(host, '.');
   sptr   = strchr(ServerName, '.');
 
-  if (sptr != NULL && hptr != NULL)
+  if (!ServerNameIsIP && sptr != NULL && hptr != NULL)
   {
    /*
     * Strip the common domain name components...
@@ -2519,7 +2549,7 @@ send_cups_browse(cupsd_printer_t *p)	/* I - Printer to send */
 
 	  httpAssembleURIf(HTTP_URI_CODING_ALL, uri, sizeof(uri), "ipp", NULL,
 	                   iface->hostname, iface->port,
-			   (p->type & CUPS_PRINTER_CLASS) ? "/classes/%s%s" :
+			   (p->type & CUPS_PRINTER_CLASS) ? "/classes/%s" :
 			                                    "/printers/%s",
 			   p->name);
 	  snprintf(packet, sizeof(packet), "%x %x %s \"%s\" \"%s\" \"%s\" %s\n",
@@ -2658,13 +2688,13 @@ send_ldap_browse(cupsd_printer_t *p)	/* I - Printer to register */
 
   sprintf(typestring, "%u", p->type);
 
-  cn_value[0]   = p->info;
+  cn_value[0]   = p->name;
   cn_value[1]   = NULL;
-  info[0]       = p->info;
+  info[0]       = p->info ? p->info : "Unknown";
   info[1]       = NULL;
-  location[0]   = p->location;
+  location[0]   = p->location ? p->location : "Unknown";
   location[1]   = NULL;
-  make_model[0] = p->make_model;
+  make_model[0] = p->make_model ? p->make_model : "Unknown";
   make_model[1] = NULL;
   type[0]       = typestring;
   type[1]       = NULL;
@@ -2672,7 +2702,7 @@ send_ldap_browse(cupsd_printer_t *p)	/* I - Printer to register */
   uri[1]        = NULL;
 
   snprintf(filter, sizeof(filter),
-           "(&(objectclass=cupsPrinter)(printerDescription~=%s))", p->info);
+           "(&(objectclass=cupsPrinter)(printerURI=%s))", p->uri);
 
   ldap_search_s(BrowseLDAPHandle, BrowseLDAPDN, LDAP_SCOPE_SUBTREE,
                 filter, (char **)ldap_attrs, 0, &res);
@@ -2694,7 +2724,7 @@ send_ldap_browse(cupsd_printer_t *p)	/* I - Printer to register */
   mods[6].mod_type = "objectClass";
   mods[6].mod_values = (char **)objectClass_values;
 
-  snprintf(dn, sizeof(dn), "cn=%s,ou=printers,%s", p->info, BrowseLDAPDN);
+  snprintf(dn, sizeof(dn), "cn=%s,ou=printers,%s", p->name, BrowseLDAPDN);
   cupsdLogMessage(CUPSD_LOG_DEBUG2, "send_ldap_browse: dn=\"%s\"", dn);
 
   if (ldap_count_entries(BrowseLDAPHandle, res) > 0)
@@ -2722,7 +2752,7 @@ send_ldap_browse(cupsd_printer_t *p)	/* I - Printer to register */
   else 
   {
    /*
-    * Printer has already been registered, modify the current
+    * Printer has never been registered, add the current
     * registration...
     */
 
@@ -2732,11 +2762,11 @@ send_ldap_browse(cupsd_printer_t *p)	/* I - Printer to register */
     for (i = 0; i < 7; i ++)
     {
       pmods[i]         = mods + i;
-      pmods[i]->mod_op = LDAP_MOD_REPLACE;
+      pmods[i]->mod_op = LDAP_MOD_ADD;
     }
     pmods[i] = NULL;
 
-    if ((rc = ldap_modify_s(BrowseLDAPHandle, dn, pmods)) != LDAP_SUCCESS)
+    if ((rc = ldap_add_s(BrowseLDAPHandle, dn, pmods)) != LDAP_SUCCESS)
       cupsdLogMessage(CUPSD_LOG_ERROR,
                       "LDAP add for %s failed with status %d: %s",
                       p->name, rc, ldap_err2string(rc));
@@ -3128,5 +3158,5 @@ slp_url_callback(
 
 
 /*
- * End of "$Id: dirsvc.c 5448 2006-04-22 03:57:26Z mike $".
+ * End of "$Id: dirsvc.c 5724 2006-07-12 19:42:35Z mike $".
  */
