@@ -1,5 +1,5 @@
 /*
- * "$Id: job.c 5494 2006-05-05 17:44:36Z mike $"
+ * "$Id: job.c 5719 2006-07-11 21:04:48Z mike $"
  *
  *   Job management routines for the Common UNIX Printing System (CUPS).
  *
@@ -506,8 +506,19 @@ cupsdFinishJob(cupsd_job_t *job)	/* I - Job */
 	  */
 
 	  cupsdStopJob(job, 0);
-	  job->state->values[0].integer = IPP_JOB_PENDING;
-	  job->state_value              = IPP_JOB_PENDING;
+
+          if (!(printer->type & CUPS_PRINTER_REMOTE) ||
+	      (printer->type & CUPS_PRINTER_IMPLICIT))
+	  {
+	   /*
+	    * Mark the job as pending again - we'll retry on another
+	    * printer...
+	    */
+
+	    job->state->values[0].integer = IPP_JOB_PENDING;
+	    job->state_value              = IPP_JOB_PENDING;
+          }
+
 	  cupsdSaveJob(job);
 
 	 /*
@@ -879,7 +890,7 @@ cupsdLoadJob(cupsd_job_t *job)		/* I - Job */
 
   if (job->attrs)
   {
-    if (job->state_value >= IPP_JOB_STOPPED)
+    if (job->state_value > IPP_JOB_STOPPED)
       job->access_time = time(NULL);
 
     return;
@@ -1753,8 +1764,8 @@ compare_active_jobs(void *first,	/* I - First job */
   int	diff;				/* Difference */
 
 
-  if ((diff = ((cupsd_job_t *)first)->priority -
-              ((cupsd_job_t *)second)->priority) != 0)
+  if ((diff = ((cupsd_job_t *)second)->priority -
+              ((cupsd_job_t *)first)->priority) != 0)
     return (diff);
   else
     return (((cupsd_job_t *)first)->id - ((cupsd_job_t *)second)->id);
@@ -2027,7 +2038,7 @@ load_job_cache(const char *filename)	/* I - job.cache filename */
     {
       cupsArrayAdd(Jobs, job);
 
-      if (job->state_value < IPP_JOB_STOPPED)
+      if (job->state_value <= IPP_JOB_STOPPED)
       {
         cupsArrayAdd(ActiveJobs, job);
 	cupsdLoadJob(job);
@@ -2285,7 +2296,7 @@ load_request_root(void)
 
       cupsArrayAdd(Jobs, job);
 
-      if (job->state_value < IPP_JOB_STOPPED)
+      if (job->state_value <= IPP_JOB_STOPPED)
         cupsArrayAdd(ActiveJobs,job);
       else
         unload_job(job);
@@ -2643,8 +2654,23 @@ start_job(cupsd_job_t     *job,		/* I - Job ID */
 
   if (job->current_file == 0)
   {
+   /*
+    * Set the processing time...
+    */
+
     set_time(job, "time-at-processing");
+
+   /*
+    * Create the backchannel pipes and make them non-blocking...
+    */
+
     cupsdOpenPipe(job->back_pipes);
+
+    fcntl(job->back_pipes[0], F_SETFL,
+          fcntl(job->back_pipes[0], F_GETFL) | O_NONBLOCK);
+
+    fcntl(job->back_pipes[1], F_SETFL,
+          fcntl(job->back_pipes[1], F_GETFL) | O_NONBLOCK);
   }
 
  /*
@@ -2996,7 +3022,7 @@ start_job(cupsd_job_t     *job,		/* I - Job ID */
   {
     snprintf(final_content_type, sizeof(final_content_type),
              "FINAL_CONTENT_TYPE=%s/%s",
-	     filter->dst->super, filter->dst->type);
+	     filter->src->super, filter->src->type);
     envp[envc ++] = final_content_type;
   }
 
@@ -3075,28 +3101,6 @@ start_job(cupsd_job_t     *job,		/* I - Job ID */
   job->status = 0;
   memset(job->filters, 0, sizeof(job->filters));
 
-  filterfds[1][0] = open("/dev/null", O_RDONLY);
-
-  if (filterfds[1][0] < 0)
-  {
-    cupsdLogMessage(CUPSD_LOG_ERROR, "Unable to open \"/dev/null\" - %s.",
-                    strerror(errno));
-    snprintf(printer->state_message, sizeof(printer->state_message),
-             "Unable to open \"/dev/null\" - %s.", strerror(errno));
-
-    cupsdAddPrinterHistory(printer);
-
-    cupsdAddEvent(CUPSD_EVENT_JOB_COMPLETED, job->printer, job,
-                  "Job canceled because the server could not open /dev/null.");
-
-    goto abort_job;
-  }
-
-  fcntl(filterfds[1][0], F_SETFD, fcntl(filterfds[1][0], F_GETFD) | FD_CLOEXEC);
-
-  cupsdLogMessage(CUPSD_LOG_DEBUG2, "start_job: filterfds[%d] = [ %d %d ]",
-                  1, filterfds[1][0], filterfds[1][1]);
-
   for (i = 0, slot = 0, filter = (mime_filter_t *)cupsArrayFirst(filters);
        filter;
        i ++, filter = (mime_filter_t *)cupsArrayNext(filters))
@@ -3150,36 +3154,43 @@ start_job(cupsd_job_t     *job,		/* I - Job ID */
 	else
 	{
 	  job->print_pipes[0] = -1;
-	  if (!strncmp(printer->device_uri, "file:/dev/", 10) &&
-	      strcmp(printer->device_uri, "file:/dev/null"))
-	    job->print_pipes[1] = open(printer->device_uri + 5,
-	                               O_WRONLY | O_EXCL);
-	  else if (!strncmp(printer->device_uri, "file:///dev/", 12) &&
-	           strcmp(printer->device_uri, "file:///dev/null"))
-	    job->print_pipes[1] = open(printer->device_uri + 7,
-	                               O_WRONLY | O_EXCL);
+	  if (!strcmp(printer->device_uri, "file:/dev/null") ||
+	      !strcmp(printer->device_uri, "file:///dev/null"))
+	    job->print_pipes[1] = -1;
 	  else
-	    job->print_pipes[1] = open(printer->device_uri + 5,
-	                               O_WRONLY | O_CREAT | O_TRUNC, 0600);
-
-	  if (job->print_pipes[1] < 0)
 	  {
-            cupsdLogMessage(CUPSD_LOG_ERROR,
-	                    "Unable to open output file \"%s\" - %s.",
-	                    printer->device_uri, strerror(errno));
-            snprintf(printer->state_message, sizeof(printer->state_message),
-		     "Unable to open output file \"%s\" - %s.",
-	             printer->device_uri, strerror(errno));
+	    if (!strncmp(printer->device_uri, "file:/dev/", 10))
+	      job->print_pipes[1] = open(printer->device_uri + 5,
+	                        	 O_WRONLY | O_EXCL);
+	    else if (!strncmp(printer->device_uri, "file:///dev/", 12))
+	      job->print_pipes[1] = open(printer->device_uri + 7,
+	                        	 O_WRONLY | O_EXCL);
+	    else if (!strncmp(printer->device_uri, "file:///", 8))
+	      job->print_pipes[1] = open(printer->device_uri + 7,
+	                        	 O_WRONLY | O_CREAT | O_TRUNC, 0600);
+	    else
+	      job->print_pipes[1] = open(printer->device_uri + 5,
+	                        	 O_WRONLY | O_CREAT | O_TRUNC, 0600);
 
-	    cupsdAddEvent(CUPSD_EVENT_JOB_COMPLETED, job->printer, job,
-                	  "Job canceled because the server could not open the "
-			  "output file.");
+	    if (job->print_pipes[1] < 0)
+	    {
+              cupsdLogMessage(CUPSD_LOG_ERROR,
+	                      "Unable to open output file \"%s\" - %s.",
+	                      printer->device_uri, strerror(errno));
+              snprintf(printer->state_message, sizeof(printer->state_message),
+		       "Unable to open output file \"%s\" - %s.",
+	               printer->device_uri, strerror(errno));
 
-            goto abort_job;
-	  }
+	      cupsdAddEvent(CUPSD_EVENT_JOB_COMPLETED, job->printer, job,
+                	    "Job canceled because the server could not open the "
+			    "output file.");
 
-	  fcntl(job->print_pipes[1], F_SETFD,
-        	fcntl(job->print_pipes[1], F_GETFD) | FD_CLOEXEC);
+              goto abort_job;
+	    }
+
+	    fcntl(job->print_pipes[1], F_SETFD,
+        	  fcntl(job->print_pipes[1], F_GETFD) | FD_CLOEXEC);
+          }
 	}
 
 	cupsdLogMessage(CUPSD_LOG_DEBUG2,
@@ -3259,25 +3270,7 @@ start_job(cupsd_job_t     *job,		/* I - Job ID */
       argv[0] = sani_uri;
 
       filterfds[slot][0] = -1;
-      filterfds[slot][1] = open("/dev/null", O_WRONLY);
-
-      if (filterfds[slot][1] < 0)
-      {
-	cupsdLogMessage(CUPSD_LOG_ERROR, "Unable to open \"/dev/null\" - %s.",
-	                strerror(errno));
-	snprintf(printer->state_message, sizeof(printer->state_message),
-        	 "Unable to open \"/dev/null\" - %s.", strerror(errno));
-
-	cupsdAddPrinterHistory(printer);
-
-	cupsdAddEvent(CUPSD_EVENT_JOB_COMPLETED, job->printer, job,
-                      "Job canceled because the server could not open a file.");
-
-        goto abort_job;
-      }
-
-      fcntl(filterfds[slot][1], F_SETFD,
-            fcntl(filterfds[slot][1], F_GETFD) | FD_CLOEXEC);
+      filterfds[slot][1] = -1;
 
       cupsdLogMessage(CUPSD_LOG_DEBUG2, "start_job: backend=\"%s\"",
                       command);
@@ -3440,5 +3433,5 @@ unload_job(cupsd_job_t *job)		/* I - Job */
 
 
 /*
- * End of "$Id: job.c 5494 2006-05-05 17:44:36Z mike $".
+ * End of "$Id: job.c 5719 2006-07-11 21:04:48Z mike $".
  */
