@@ -1,5 +1,5 @@
 /*
- * "$Id: printers.c 5491 2006-05-04 20:53:35Z mike $"
+ * "$Id: printers.c 5724 2006-07-12 19:42:35Z mike $"
  *
  *   Printer routines for the Common UNIX Printing System (CUPS).
  *
@@ -62,6 +62,7 @@
  */
 
 #include "cupsd.h"
+#include <cups/dir.h>
 
 
 /*
@@ -257,6 +258,11 @@ cupsdCreateCommonData(void)
 {
   int			i;		/* Looping var */
   ipp_attribute_t	*attr;		/* Attribute data */
+  cups_dir_t		*dir;		/* Notifier directory */
+  cups_dentry_t		*dent;		/* Notifier directory entry */
+  cups_array_t		*notifiers;	/* Notifier array */
+  char			filename[1024],	/* Filename */
+			*notifier;	/* Current notifier */
   static const int nups[] =		/* number-up-supported values */
 		{ 1, 2, 4, 6, 9, 16 };
   static const ipp_orient_t orients[4] =/* orientation-requested-supported values */
@@ -502,11 +508,11 @@ cupsdCreateCommonData(void)
   ippAddInteger(CommonData, IPP_TAG_PRINTER, IPP_TAG_INTEGER,
                "notify-max-events-supported", MaxEvents);
 
-  /* notify-notify-events-default */
+  /* notify-events-default */
   ippAddString(CommonData, IPP_TAG_PRINTER, IPP_TAG_KEYWORD,
                "notify-events-default", NULL, "job-completed");
 
-  /* notify-notify-events-supported */
+  /* notify-events-supported */
   ippAddStrings(CommonData, IPP_TAG_PRINTER, IPP_TAG_KEYWORD,
                 "notify-events-supported",
 		(int)(sizeof(notify_events) / sizeof(notify_events[0])),
@@ -516,10 +522,32 @@ cupsdCreateCommonData(void)
   ippAddString(CommonData, IPP_TAG_PRINTER, IPP_TAG_KEYWORD,
                "notify-pull-method-supported", NULL, "ippget");
 
-  /* TODO: scan notifier directory */
   /* notify-schemes-supported */
-  ippAddString(CommonData, IPP_TAG_PRINTER, IPP_TAG_KEYWORD,
-               "notify-schemes-supported", NULL, "mailto");
+  snprintf(filename, sizeof(filename), "%s/notifier", ServerBin);
+  if ((dir = cupsDirOpen(filename)) != NULL)
+  {
+    notifiers = cupsArrayNew((cups_array_func_t)strcmp, NULL);
+
+    while ((dent = cupsDirRead(dir)) != NULL)
+      if (S_ISREG(dent->fileinfo.st_mode) &&
+          (dent->fileinfo.st_mode & S_IXOTH) != 0)
+        cupsArrayAdd(notifiers, _cupsStrAlloc(dent->filename));
+
+    if (cupsArrayCount(notifiers) > 0)
+    {
+      attr = ippAddStrings(CommonData, IPP_TAG_PRINTER, IPP_TAG_KEYWORD,
+        	           "notify-schemes-supported",
+			   cupsArrayCount(notifiers), NULL, NULL);
+
+      for (i = 0, notifier = (char *)cupsArrayFirst(notifiers);
+           notifier;
+	   i ++, notifier = (char *)cupsArrayNext(notifiers))
+	attr->values[i].string.text = notifier;
+    }
+
+    cupsArrayDelete(notifiers);
+    cupsDirClose(dir);
+  }
 
   /* number-up-supported */
   ippAddIntegers(CommonData, IPP_TAG_PRINTER, IPP_TAG_INTEGER,
@@ -618,6 +646,9 @@ cupsdDeletePrinter(
 
   cupsArrayRemove(Printers, p);
 
+  if (p->type & CUPS_PRINTER_IMPLICIT)
+    cupsArrayRemove(ImplicitPrinters, p);
+
  /*
   * Remove the dummy interface/icon/option files under IRIX...
   */
@@ -665,7 +696,7 @@ cupsdDeletePrinter(
 	   dp = (cupsd_printer_t *)cupsArrayNext(Printers))
 	if (dp != p && (dp->type & CUPS_PRINTER_DEFAULT))
 	{
-	  DefaultPrinter = p;
+	  DefaultPrinter = dp;
 	  break;
 	}
     }
@@ -1233,6 +1264,7 @@ cupsdRenamePrinter(
   */
 
   cupsArrayAdd(Printers, p);
+
   if (p->type & CUPS_PRINTER_IMPLICIT)
     cupsArrayAdd(ImplicitPrinters, p);
 }
@@ -2924,10 +2956,6 @@ add_printer_formats(cupsd_printer_t *p)	/* I - Printer */
        type;
        type = mimeNextType(MimeDatabase))
   {
-    if (!strcasecmp(type->super, "application") &&
-	!strcasecmp(type->type, "octet-stream"))
-      continue;
-
     snprintf(mimetype, sizeof(mimetype), "%s/%s", type->super, type->type);
 
     if ((filters = mimeFilter(MimeDatabase, type, p->filetype, NULL)) != NULL)
@@ -2953,14 +2981,20 @@ add_printer_formats(cupsd_printer_t *p)	/* I - Printer */
   * Add the file formats that can be filtered...
   */
 
+  if ((type = mimeType(MimeDatabase, "application", "octet-stream")) == NULL ||
+      !cupsArrayFind(p->filetypes, type))
+    i = 1;
+  else
+    i = 0;
 
   attr = ippAddStrings(p->attrs, IPP_TAG_PRINTER, IPP_TAG_MIMETYPE,
                        "document-format-supported",
 		       cupsArrayCount(p->filetypes) + 1, NULL, NULL);
 
-  attr->values[0].string.text = _cupsStrAlloc("application/octet-stream");
+  if (i)
+    attr->values[0].string.text = _cupsStrAlloc("application/octet-stream");
 
-  for (i = 1, type = (mime_type_t *)cupsArrayFirst(p->filetypes);
+  for (type = (mime_type_t *)cupsArrayFirst(p->filetypes);
        type;
        i ++, type = (mime_type_t *)cupsArrayNext(p->filetypes))
   {
@@ -3033,7 +3067,7 @@ write_irix_config(cupsd_printer_t *p)	/* I - Printer to update */
 {
   char		filename[1024];		/* Interface script filename */
   cups_file_t	*fp;			/* Interface script file */
-
+  ipp_attribute_t *attr;		/* Attribute data */
 
 
  /*
@@ -3278,5 +3312,5 @@ write_irix_state(cupsd_printer_t *p)	/* I - Printer to update */
 
 
 /*
- * End of "$Id: printers.c 5491 2006-05-04 20:53:35Z mike $".
+ * End of "$Id: printers.c 5724 2006-07-12 19:42:35Z mike $".
  */
